@@ -50,6 +50,24 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
         <translation>Dona</translation>
     </message>
 </context>
+<context>
+    <name>AddStreamingMediaDialog</name>
+    <message>
+        <location filename="../ui/addstreamingmediadialog.ui" line="14"/>
+        <source>Add audio stream</source>
+        <translation>Aggiungi flusso audio</translation>
+    </message>
+    <message>
+        <location filename="../ui/addstreamingmediadialog.ui" line="27"/>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <location filename="../ui/addstreamingmediadialog.ui" line="34"/>
+        <source>Name</source>
+        <translation>Titolo</translation>
+    </message>
+</context>
 <context>
     <name>DirectoryView</name>
     <message>
@@ -412,70 +430,85 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
         <translation>Lettore</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="67"/>
+        <location filename="../ui/mainwindow.ui" line="68"/>
         <source>Help</source>
         <translation>Aiuto</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="79"/>
+        <location filename="../ui/mainwindow.ui" line="80"/>
         <source>About</source>
         <translation>About</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="84"/>
+        <location filename="../ui/mainwindow.ui" line="85"/>
         <source>Settings</source>
         <translation>Impostazioni</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="89"/>
+        <location filename="../ui/mainwindow.ui" line="90"/>
         <source>Manage library</source>
         <translation>Gestisci collezione</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="94"/>
+        <location filename="../ui/mainwindow.ui" line="95"/>
         <source>Equalizer</source>
         <translation>Equalizzatore</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="99"/>
+        <location filename="../ui/mainwindow.ui" line="100"/>
         <source>Set timer</source>
         <translation>Imposta timer</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="104"/>
+        <location filename="../ui/mainwindow.ui" line="105"/>
         <source>Save playlist</source>
         <translation>Salva playlist</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="107"/>
+        <location filename="../ui/mainwindow.ui" line="108"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="112"/>
+        <location filename="../ui/mainwindow.ui" line="113"/>
         <source>Online help</source>
         <translation>Aiuto online</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="117"/>
+        <location filename="../ui/mainwindow.ui" line="118"/>
         <source>Import playlists</source>
         <translation>Importa playlist</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="226"/>
+        <location filename="../ui/mainwindow.ui" line="123"/>
+        <source>Add stream</source>
+        <translation>Aggiungi stream</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="228"/>
         <source>Clear playlist?</source>
         <translation>Cancellare la playlist?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="272"/>
+        <location filename="../mainwindow.cpp" line="274"/>
         <source>Music off: </source>
         <translation>Spegnimento musica: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="485"/>
+        <location filename="../mainwindow.cpp" line="487"/>
         <source>Select directory</source>
         <translation>Seleziona cartella</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="501"/>
+        <source>Internet radio</source>
+        <translation>Internet radio</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="501"/>
+        <source>Audio stream</source>
+        <translation>Audio stream</translation>
+    </message>
 </context>
 <context>
     <name>ManageLibraryForm</name>
@@ -560,45 +593,45 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
     </message>
     <message>
         <location filename="../playerform.cpp" line="91"/>
-        <location filename="../playerform.cpp" line="783"/>
+        <location filename="../playerform.cpp" line="788"/>
         <source>Clear playlist</source>
         <translation>Cancella playlist</translation>
     </message>
     <message>
         <location filename="../playerform.cpp" line="92"/>
-        <location filename="../playerform.cpp" line="784"/>
+        <location filename="../playerform.cpp" line="789"/>
         <source>Delete</source>
         <translation>Cancella</translation>
     </message>
     <message>
         <location filename="../playerform.cpp" line="93"/>
-        <location filename="../playerform.cpp" line="242"/>
-        <location filename="../playerform.cpp" line="282"/>
-        <location filename="../playerform.cpp" line="785"/>
+        <location filename="../playerform.cpp" line="243"/>
+        <location filename="../playerform.cpp" line="283"/>
+        <location filename="../playerform.cpp" line="790"/>
         <source>Add to favorites</source>
         <translation>Aggiungi ai preferiti</translation>
     </message>
     <message>
         <location filename="../playerform.cpp" line="94"/>
-        <location filename="../playerform.cpp" line="786"/>
+        <location filename="../playerform.cpp" line="791"/>
         <source>Enqueue</source>
         <translation>Metti in coda</translation>
     </message>
     <message>
         <location filename="../playerform.cpp" line="95"/>
-        <location filename="../playerform.cpp" line="787"/>
+        <location filename="../playerform.cpp" line="792"/>
         <source>Add to playlists</source>
         <translation>Aggiungi alle playlist</translation>
     </message>
     <message>
         <location filename="../playerform.cpp" line="96"/>
-        <location filename="../playerform.cpp" line="788"/>
+        <location filename="../playerform.cpp" line="793"/>
         <source>Edit tags</source>
         <translation>Modifica le tag</translation>
     </message>
     <message>
-        <location filename="../playerform.cpp" line="242"/>
-        <location filename="../playerform.cpp" line="282"/>
+        <location filename="../playerform.cpp" line="243"/>
+        <location filename="../playerform.cpp" line="283"/>
         <source>Remove from favorites</source>
         <translation>Rimuovi dai preferiti</translation>
     </message>
@@ -636,7 +669,7 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
     </message>
     <message>
         <location filename="../ui/saveplaylistdialog.ui" line="26"/>
-        <source>Existed playlists:</source>
+        <source>Existing playlists:</source>
         <translation>Playlist esistenti:</translation>
     </message>
     <message>
@@ -764,10 +797,6 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
         <source>Language:</source>
         <translation>Lingua:</translation>
     </message>
-    <message>
-        <source>Italiano</source>
-        <translation type="obsolete">Italiano</translation>
-    </message>
     <message>
         <location filename="../ui/settingsform.ui" line="438"/>
         <source>Sort album:</source>
