@@ -42,6 +42,21 @@ By Nikolay Tischenko (somebody)&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;&lt;b
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>AddStreamingMediaDialog</name>
+    <message>
+        <source>URL</source>
+        <translation>URL</translation>
+    </message>
+    <message>
+        <source>Name</source>
+        <translation>名稱</translation>
+    </message>
+    <message>
+        <source>Add audio stream</source>
+        <translation>添加音頻流</translation>
+    </message>
+</context>
 <context>
     <name>DirectoryView</name>
     <message>
@@ -383,6 +398,18 @@ By Nikolay Tischenko (somebody)&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;&lt;b
         <source>Select directory</source>
         <translation>選擇目錄</translation>
     </message>
+    <message>
+        <source>Add stream</source>
+        <translation>新增流</translation>
+    </message>
+    <message>
+        <source>Internet radio</source>
+        <translation>互聯網廣播</translation>
+    </message>
+    <message>
+        <source>Audio stream</source>
+        <translation>音頻流</translation>
+    </message>
 </context>
 <context>
     <name>ManageLibraryForm</name>
@@ -506,7 +533,7 @@ By Nikolay Tischenko (somebody)&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;&lt;b
         <translation>新建:</translation>
     </message>
     <message>
-        <source>Existed playlists:</source>
+        <source>Existing playlists:</source>
         <translation>現有播放清單:</translation>
     </message>
     <message>
@@ -644,10 +671,6 @@ By Nikolay Tischenko (somebody)&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;&lt;b
         <source>Show track length in library view:</source>
         <translation>在音樂庫檢視顯示歌曲長度:</translation>
     </message>
-    <message>
-        <source>Italiano</source>
-        <translation type="obsolete">Italiano</translation>
-    </message>
 </context>
 <context>
     <name>TimerDialog</name>
